Crate gittwo

Crate gittwo 

Re-exports

pub extern crate git2;

Structs

AddConfig
CheckoutConfig
CloneConfig
Specifies details for a git clone operation.
CommitConfig
FetchConfig
GitRepository
InitConfig
PushConfig
RemoteConfig
A struct used to specify various details about the git remote command.

Enums

AddFlags
CheckoutFlags
CloneFlags
Represents flags that can be applied to a git clone command. See git clone documentation for more details on each flag.
CommitFlags
CredType
FetchFlags
InitFlags
PushFlags
RemoteFlags
RemoteSubCommand